Screener
**************************

Getting screener information.

Overview
=============

.. automodule:: finvizfinance.screener.overview
   :members:

Valuation
=============

.. automodule:: finvizfinance.screener.valuation
   :members:

Financial
=============

.. automodule:: finvizfinance.screener.financial
   :members:

Ownership
=============

.. automodule:: finvizfinance.screener.ownership
   :members:

Technical
=============

.. automodule:: finvizfinance.screener.technical
   :members:

Custom
=============

.. automodule:: finvizfinance.screener.custom
   :members:

Tickers
=============

.. automodule:: finvizfinance.screener.ticker
   :members:
